django-simple-history |pypi-version|
====================================

.. Start of PyPI readme

|build-status| |docs| |coverage| |maintainability| |code-style| |downloads|

.. |pypi-version| image:: https://img.shields.io/pypi/v/django-simple-history.svg
   :target: https://pypi.org/project/django-simple-history/
   :alt: PyPI Version

.. |build-status| image:: https://github.com/django-commons/django-simple-history/actions/workflows/test.yml/badge.svg
   :target: https://github.com/django-commons/django-simple-history/actions/workflows/test.yml
   :alt: Build Status

.. |docs| image:: https://readthedocs.org/projects/django-simple-history/badge/?version=latest
   :target: https://django-simple-history.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. |coverage| image:: https://img.shields.io/codecov/c/github/django-commons/django-simple-history/master.svg
   :target: https://app.codecov.io/github/django-commons/django-simple-history?branch=master
   :alt: Test Coverage

.. |maintainability| image:: https://api.codeclimate.com/v1/badges/66cfd94e2db991f2d28a/maintainability
   :target: https://codeclimate.com/github/django-commons/django-simple-history/maintainability
   :alt: Maintainability

.. |code-style| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code Style

.. |downloads| image:: https://static.pepy.tech/badge/django-simple-history
   :target: https://pepy.tech/project/django-simple-history
   :alt: Downloads


``django-simple-history`` stores Django model state on every create/update/delete.

This app supports the following combinations of Django and Python:

==========  ========================
  Django      Python
==========  ========================
4.2         3.10, 3.11, 3.12, 3.13
5.0         3.10, 3.11, 3.12, 3.13
5.1         3.10, 3.11, 3.12, 3.13
5.2         3.10, 3.11, 3.12, 3.13, 3.14
6.0         3.12, 3.13, 3.14
main        3.12, 3.13, 3.14
==========  ========================

Getting Help
------------

Documentation is available at https://django-simple-history.readthedocs.io/en/stable/

Pull requests are welcome. Read the `CONTRIBUTING`_ file for tips on
submitting a pull request.

.. _CONTRIBUTING: https://github.com/django-commons/django-simple-history/blob/master/CONTRIBUTING.rst

License
-------

This project is licensed under the
`BSD 3-Clause license <https://choosealicense.com/licenses/bsd-3-clause/>`_.
